@@ -21,11 +21,16 @@
 use strict;
 
 use File::stat;
-use Gnome2;
-use Gtk2::GladeXML;
 use POSIX qw(waitpid);
 use Getopt::Long;
-use Config::IniFiles;
+
+eval "use Config::IniFiles;";
+if ($@)
+  {
+    print "The Config::IniFiles perl module needs to be installed!\n".
+      "Please refer to README file.\n";
+    exit;
+  }
 
 use lib '/usr/local/lib/movixmaker-2';
 use lib '/usr/lib/movixmaker-2';
@@ -35,18 +40,17 @@ use config;
 use constant FALSE => 0;
 use constant TRUE => !FALSE;
 
-use vars qw($xml_root $child_pid
-            $NAME
+use vars qw($NAME $xml_root $child_pid $mkisocmd
             $glade_dir $config_file $movixversion
             $diag_feedback $diag_properties
-            $statusbar $mkisocmd $installed_emovix
-            $destpath $srcpath $tmpfolder $help
-            $destination $srcdir $current_path
-            $opt_verbose $opt_debug $opt_lang $opt_kblayout
+            $statusbar $installed_emovix $tmpfolder
+            $destpath $srcpath $help $destination $srcdir $current_path
+            $opt_verbose $opt_debug $opt_boot_help_lang $opt_menu_lang
+            $opt_kblayout
             $opt_qt $opt_asf $opt_wmv $opt_tmpdir $opt_fontset $opt_nodelete
             $opt_loop $opt_random $opt_reboot $opt_shut $opt_eject $opt_nodma
-            $opt_bootlabel $opt_version
-            @languages @kblayouts @fontsets $bootlabels
+            $opt_bootlabel $opt_version $opt_nogui
+            @boot_help_langs @kblayouts @fontsets $bootlabels
             @extra_mkisofs_options $extra_mkisofs_options
             @extra_mplayer_options $extra_mplayer_options
             @unwanted_mplayer_options $unwanted_mplayer_options
@@ -54,20 +58,6 @@ use vars qw($xml_root $child_pid
 
 $NAME="MoviXMaker-2";
 
-$current_path = $0;
-$current_path =~ s/movixmaker-2(\.pl)?$//;
-
-if ($0 =~ /^\.\//) {
-  $config_file = 'movixmaker-2.conf';
-  $glade_dir= '.';
-} else {
-  $config_file = $config::sysconfdir . '/movixmaker-2.conf';
-  $glade_dir = "$current_path../share/movixmaker-2/glade";
-}
-
-# Reading the Configuration File
-read_config();
-
 # Retrieve options from command line
 GetOptions (
 # 	    "title=s"             => \$title,
@@ -87,7 +77,8 @@ GetOptions (
  	    "nodelete!"           => \$opt_nodelete,
 	    "movixDir=s"          => \$srcpath,
  	    "subtitleFonts=s"     => \$opt_fontset,
-	    "language=s"          => \$opt_lang,
+	    "boot-help-lang=s"    => \$opt_boot_help_lang,
+ 	    "menu-lang=s"         => \$opt_menu_lang,
 	    "keyboard=s"          => \$opt_kblayout,
 	    "hasQT!"              => \$opt_qt,
 	    "hasWMV!"             => \$opt_wmv,
@@ -95,6 +86,7 @@ GetOptions (
 	    "verbose!"            => \$opt_verbose,
 	    "debug!"              => \$opt_debug,
 # 	    "movix-version"       => \$version,
+	    "nogui!"              => \$opt_nogui,
  	    "version"             => \$opt_version,
 	    'help|?'              => \$help
 	    );
@@ -103,18 +95,72 @@ if( defined $help ){
   help();
   exit;
 } elsif( defined $opt_version ){
-  print "MoviXMaker $config::version\n";
+  print "MoviXMaker-2 $config::version\n";
   exit;
 }
-#################################
 
-prepare_interface();
+# MoviXMaker is started in cmdline mode.
+if (defined $opt_nogui)
+  {
+    print "You've choosen not to use the GUI.\n";
+
+    if (!defined $srcpath) {
+      print STDERR "You need to specify the movixDir!\n";
+      exit;
+    }
+  }
+# The graphical interface is to be shown
+else
+  {
+    # Trying to load the Gnome perl module
+    eval "use Gnome2;";
+    if ($@) {
+      $opt_nogui = TRUE;
+      error("The Gnome2 perl module needs to be installed!\n".
+	    "Please refer to README file.\n".
+	    "-> Falling back to command line interface.\n");
+    }
+    # Trying to load the GladeXML perl module
+    eval "use Gtk2::GladeXML;";
+    if ($@) {
+      $opt_nogui = TRUE;
+      error("The Gtk2::GladeXML perl module needs to be installed!\n".
+	    "Please refer to README file.\n".
+	    "-> Falling back to command line interface.\n");
+    }
+  }
+#######################################
+
+$current_path = $0;
+$current_path =~ s/movixmaker-2(\.pl)?$//;
+
+if ($0 =~ /^\.\//) {
+  $config_file = 'movixmaker-2.conf';
+  $glade_dir= '.';
+} else {
+  $config_file = $config::sysconfdir . '/movixmaker-2.conf';
+  $glade_dir = "$current_path../share/movixmaker-2/glade";
+}
+
+# Reading the Configuration File
+read_config();
 
 $SIG{CHLD} = \&child_dead;
 $SIG{__WARN__} = \&Carp::cluck;
+#################################
 
-main Gtk2;
-exit;
+if (defined $opt_nogui)
+  {
+    set_options();
+    get_options();
+    prepare_iso();
+  }
+else
+  {
+    prepare_interface();
+    main Gtk2;
+  }
+exit; # Useless ?
 ### end main
 
 sub child_dead {
@@ -129,40 +175,42 @@ sub read_config {
   my $cfg = new Config::IniFiles( -file => "$config_file" );
 
   # Global options
-  $opt_debug = $cfg->val('MoviXMaker','debug');
-  $opt_verbose = $cfg->val('MoviXMaker','verbose');
-  $opt_nodelete = $cfg->val('MoviXMaker','nodelete');
+  $opt_debug = $cfg->val('MoviXMaker','debug') if (!defined $opt_debug);
+  $opt_verbose = $cfg->val('MoviXMaker','verbose') if (!defined $opt_verbose);
+  $opt_nodelete = $cfg->val('MoviXMaker','nodelete')
+    if (!defined $opt_nodelete);
 
   ## *MoviX* options
   # video codecs
-  $opt_asf = $cfg->val('MoviX','asf');
-  $opt_qt = $cfg->val('MoviX','qt');
-  $opt_wmv = $cfg->val('MoviX','wmv');
+  $opt_asf = $cfg->val('MoviX','asf') if (!defined $opt_asf);
+  $opt_qt = $cfg->val('MoviX','qt') if (!defined $opt_qt);
+  $opt_wmv = $cfg->val('MoviX','wmv') if (!defined $opt_wmv);
   # parameters
-  $opt_bootlabel = $cfg->val('MoviX','bootlabel');
-  $opt_lang = $cfg->val('MoviX','language');
-  $opt_kblayout = $cfg->val('MoviX','kblayout');
-  $opt_fontset = $cfg->val('MoviX','fontset');
-  $opt_loop = $cfg->val('MoviX','loop');
-  $opt_random = $cfg->val('MoviX','random');
-  $opt_shut = $cfg->val('MoviX','shutdown');
-  $opt_reboot = $cfg->val('MoviX','reboot');
-  $opt_eject = $cfg->val('MoviX','eject');
-  $opt_nodma = $cfg->val('MoviX','nodma');
+  $opt_bootlabel = $cfg->val('MoviX','bootlabel') if (!defined $opt_bootlabel);
+  $opt_boot_help_lang = $cfg->val('MoviX','boot_help_lang') if (!defined $opt_boot_help_lang);
+  $opt_menu_lang = $cfg->val('MoviX','boot_help_lang') if (!defined $opt_menu_lang);
+  $opt_kblayout = $cfg->val('MoviX','kblayout') if (!defined $opt_kblayout);
+  $opt_fontset = $cfg->val('MoviX','fontset') if (!defined $opt_fontset);
+  $opt_loop = $cfg->val('MoviX','loop') if (!defined $opt_loop);
+  $opt_random = $cfg->val('MoviX','random') if (!defined $opt_random);
+  $opt_shut = $cfg->val('MoviX','shutdown') if (!defined $opt_shut);
+  $opt_reboot = $cfg->val('MoviX','reboot') if (!defined $opt_reboot);
+  $opt_eject = $cfg->val('MoviX','eject') if (!defined $opt_eject);
+  $opt_nodma = $cfg->val('MoviX','nodma') if (!defined $opt_nodma);
 
   # Other options
-  @extra_mkisofs_options = $cfg->val('Others','extra_mkisofs_options');
-  @extra_mplayer_options = $cfg->val('Others','extra_mplayer_options');
-  @unwanted_mplayer_options = $cfg->val('Others','unwanted_mplayer_options');
+  @extra_mkisofs_options = $cfg->val('Others','extra_mkisofs_options')
+    if (!defined @extra_mkisofs_options);
+  @extra_mplayer_options = $cfg->val('Others','extra_mplayer_options')
+    if (!defined @extra_mplayer_options);
+  @unwanted_mplayer_options = $cfg->val('Others','unwanted_mplayer_options')
+    if (!defined @unwanted_mplayer_options);
 }
 
 ### callbacks
-sub on_exit_activate {
-  Gtk2->main_quit;
-}
 
 # The user actually quit the application
-sub on_MoviXMaker_destroy {
+sub on_exit_activate {
   Gtk2->main_quit;
 }
 
@@ -182,7 +230,13 @@ sub about_activate {
 				       'MoviXMaker is a Perl GTK+-2/Gnome2 interface to create customized [e]MoviX[2] ISO files.
 It is available under the terms of the GPL.',
 				       'Pascal Giard <evilynux@users.sf.net>');
-  $about_diag->show ();
+  $about_diag->show();
+
+  # Shit for testing...
+#  my $menuitem1 = Gtk2::CheckMenuItem->new_with_label("Patate");
+#  $menuitem1->set_name("pa");
+#  $xml_root->get_widget("optionmenu_menu_lang")->get_menu->append($menuitem1);
+#  $menuitem1->show;
 }
 
 sub on_button_create_released {
@@ -203,6 +257,7 @@ sub on_fbbutton_released {
   reenable();
 }
 
+# An option as been modified in the Edit/Properties' window
 sub on_option_change {
   $xml_root->get_widget ("prop_apply_btn")->set_sensitive (TRUE);
 }
@@ -229,9 +284,16 @@ sub update_options {
   $xml_root->get_widget ("combo_bootlabels")->set_value_in_list(TRUE, FALSE);
   $xml_root->get_widget ("entry_bootlabel")->set_text($opt_bootlabel);
 
-  $xml_root->get_widget ("combo_languages")->set_popdown_strings(@languages);
-  $xml_root->get_widget ("combo_languages")->set_value_in_list(FALSE, FALSE);
-  $xml_root->get_widget ("entry_language")->set_text($opt_lang);
+  $xml_root->get_widget ("combo_boot_help_langs")->
+    set_popdown_strings(@boot_help_langs);
+  $xml_root->get_widget ("combo_boot_help_langs")->
+    set_value_in_list(FALSE, FALSE);
+  $xml_root->get_widget ("entry_boot_help_lang")->
+    set_text($opt_boot_help_lang);
+
+  ##
+  # *** FIXME: support for opt_menu_lang should be added
+  ##
 
   $xml_root->get_widget ("combo_fontsets")->set_popdown_strings(@fontsets);
   $xml_root->get_widget ("combo_fontsets")->set_value_in_list(FALSE, FALSE);
@@ -247,23 +309,32 @@ sub set_options {
   ## MoviXMaker options
   #######
 
-  # Debug mode.
-  $xml_root->get_widget ("cb_debug")->set_active($opt_debug);
+  # If the graphical interface isn't disabled.
+  if (!defined $opt_nogui) {
+    # Debug mode.
+    $xml_root->get_widget ("cb_debug")->set_active($opt_debug);
 
-  # Verbose mkisofs output.
-  $xml_root->get_widget ("cb_verbose")->set_active($opt_verbose);
+    # Verbose mkisofs output.
+    $xml_root->get_widget ("cb_verbose")->set_active($opt_verbose);
 
-  # Donnot delete tmp directory
-  $xml_root->get_widget ("cb_nodelete")->set_active($opt_nodelete);
+    # Donnot delete tmp directory
+    $xml_root->get_widget ("cb_nodelete")->set_active($opt_nodelete);
+  }
 
   # Temporary directory.
   if (defined $opt_tmpdir && $opt_tmpdir ) {
     $opt_tmpdir =~ s/\.$//;
     $opt_tmpdir =~ s/([^\/])$/$1\// ;
+  # GNU standard : tmpdir defined in the environment variables.
+  } elsif (exists $ENV{'TMPDIR'}) {
+    $opt_tmpdir = $ENV{'TMPDIR'};
+    $opt_tmpdir =~ s/\.$//;
+    $opt_tmpdir =~ s/([^\/])$/$1\// ;
   } else {
     $opt_tmpdir = "/tmp/";
   }
-  $xml_root->get_widget ("tmpdir_entry")->set_text($opt_tmpdir);
+  $xml_root->get_widget ("tmpdir_entry")->set_text($opt_tmpdir)
+    unless (defined $opt_nogui);
 
   #######
   ## mkisofs options
@@ -272,7 +343,7 @@ sub set_options {
     $extra_mkisofs_options =
       join(' ',split(/,/,join(',',@extra_mkisofs_options)));
     $xml_root->get_widget ("entry_extra_mkisofs_options")->
-	set_text($extra_mkisofs_options);
+	set_text($extra_mkisofs_options) unless (defined $opt_nogui);;
   }
   #######
   ## mplayer options
@@ -281,21 +352,23 @@ sub set_options {
     $extra_mplayer_options = 
       join(' ',split(/,/,join(',',@extra_mplayer_options)));
     $xml_root->get_widget ("entry_extra_mplayer_options")->
-	set_text($extra_mplayer_options);
+	set_text($extra_mplayer_options) unless (defined $opt_nogui);;
   }
 
   if (@unwanted_mplayer_options > 0) {
     $unwanted_mplayer_options = 
       join(' ',split(/,/,join(',',@unwanted_mplayer_options)));
     $xml_root->get_widget ("entry_unwanted_mplayer_options")->
-			       set_text($unwanted_mplayer_options);
+      set_text($unwanted_mplayer_options) unless (defined $opt_nogui);;
   }
   #######
   ## [e]MoviX[] Options
   #######
-  my $dest_file = $xml_root->get_widget ("destdir_entry");
+  my $dest_file = $xml_root->get_widget ("destdir_entry")
+    unless (defined $opt_nogui);
+
   if ( defined $destpath ) {
-    my $pwd = `pwd`;
+    my $pwd = `echo -n \$(pwd)`;
     $destpath =~ s/^\.[^\.]?\//$pwd\//; # if relative path, making it
                                         # absolute
     $destpath =~ s/\n//;              # removing trailing CR if present
@@ -305,9 +378,11 @@ sub set_options {
       $destpath =~ s/(.+)$/$1movix\.iso/; # $destpath has to point
                                           # to a file.
     }
-    $dest_file->set_text($destpath);
+    $dest_file->set_text($destpath) unless (defined $opt_nogui);
   } else {
-    $dest_file->set_text($opt_tmpdir . "movix.iso");
+    # No destination file/dir as been specified, using default.
+    $dest_file->set_text($opt_tmpdir . "movix.iso")
+      unless (defined $opt_nogui);
   }
 
   if ( defined $srcpath ) {
@@ -318,144 +393,163 @@ sub set_options {
     chdir $orig;
 
     $srcpath =~ s/([^\/])$/$1\// ; # Add a trailing /
-    $xml_root->get_widget ("srcdir_entry")->set_text($srcpath);
+    $xml_root->get_widget ("srcdir_entry")->set_text($srcpath)
+      unless (defined $opt_nogui);
 
     using_installed_emovix();
   } else {
     using_installed_emovix();
-    if (defined $srcpath) {
+    if (defined $srcpath and !defined $opt_nogui) {
       $xml_root->get_widget ("srcdir_entry")->set_text($srcpath);
     }
   }
 
-  # Default language.
-  if (defined $opt_lang) {
-    $xml_root->get_widget ("entry_language")->set_text($opt_lang);
-  }
-  # Default keyboard layout.
-  if (defined $opt_kblayout && $opt_kblayout) {
-    $xml_root->get_widget ("entry_kblayout")->
+  if (!defined $opt_nogui) {
+    # Default boot help language.
+    if (defined $opt_boot_help_lang) {
+      $xml_root->get_widget ("entry_boot_help_lang")->set_text($opt_boot_help_lang);
+    }
+
+    ##
+    # *** FIXME : opt_menu_lang needs to be handled.
+    ##
+
+    # Default keyboard layout.
+    if (defined $opt_kblayout && $opt_kblayout) {
+      $xml_root->get_widget ("entry_kblayout")->
 	set_text($opt_kblayout);
-  }
+    }
 
-  # Default fontset.
-  if (defined $opt_fontset && $opt_fontset) {
-    $xml_root->get_widget ("entry_fontset")->
+    # Default fontset.
+    if (defined $opt_fontset && $opt_fontset) {
+      $xml_root->get_widget ("entry_fontset")->
 	set_text($opt_fontset);
-  }
+    }
 
-  # Default boot label.
-  if (defined $opt_bootlabel && $opt_bootlabel) {
-    $xml_root->get_widget ("entry_bootlabel")->
+    # Default boot label.
+    if (defined $opt_bootlabel && $opt_bootlabel) {
+      $xml_root->get_widget ("entry_bootlabel")->
 	set_text($opt_bootlabel);
+    }
+
+    # Include Quicktime codecs ?
+    $xml_root->get_widget ("cb_qt")->set_active($opt_qt);
+
+    # Include ASF codecs ?
+    $xml_root->get_widget ("cb_asf")->set_active($opt_asf);
+
+    # Include WMV codecs ?
+    $xml_root->get_widget ("cb_wmv")->set_active($opt_wmv);
+
+    # Play movies in random order
+    $xml_root->get_widget ("cb_random")->set_active($opt_random);
+
+    # Power off PC after playing all CD files
+    $xml_root->get_widget ("cb_shut")->set_active($opt_shut);
+
+    # Reboot PC after playing all CD files
+    $xml_root->get_widget ("cb_reboot")->set_active($opt_reboot);
+
+    # Eject the CD
+    $xml_root->get_widget ("cb_eject")->set_active($opt_eject);
+
+    # Disable DMA
+    $xml_root->get_widget ("cb_nodma")->set_active($opt_nodma);
+
+    # Loop N times the playlist
+    if (defined $opt_loop && $opt_loop) {
+      $xml_root->get_widget ("spinbutton_loop")->set_value($opt_loop);
+    }
+
+    # Renders the apply button insensitive
+    $xml_root->get_widget ("prop_apply_btn")->set_sensitive(FALSE);
   }
-
-  # Include Quicktime codecs ?
-  $xml_root->get_widget ("cb_qt")->set_active($opt_qt);
-
-  # Include ASF codecs ?
-  $xml_root->get_widget ("cb_asf")->set_active($opt_asf);
-
-  # Include WMV codecs ?
-  $xml_root->get_widget ("cb_wmv")->set_active($opt_wmv);
-
-  # Play movies in random order
-  $xml_root->get_widget ("cb_random")->set_active($opt_random);
-
-  # Power off PC after playing all CD files
-  $xml_root->get_widget ("cb_shut")->set_active($opt_shut);
-
-  # Reboot PC after playing all CD files
-  $xml_root->get_widget ("cb_reboot")->set_active($opt_reboot);
-
-  # Eject the CD
-  $xml_root->get_widget ("cb_eject")->set_active($opt_eject);
-
-  # Disable DMA
-  $xml_root->get_widget ("cb_nodma")->set_active($opt_nodma);
-
-  # Loop N times the playlist
-  if (defined $opt_loop && $opt_loop) {
-    $xml_root->get_widget ("entry_loop")->set_text($opt_loop);
-  }
-
-  # Renders the apply button insensitive
-  $xml_root->get_widget ("prop_apply_btn")->set_sensitive(FALSE);
 }
 
+# Take the options from the view and update the ones in the model
 sub get_options {
 
   ## MoviXMaker options
   #######
-  # Debug mode.
-  $opt_debug =
-    $xml_root->get_widget ("cb_debug")->get_active || 0;
+  if (!defined $opt_nogui) {
+    # Debug mode.
+    $opt_debug =
+      $xml_root->get_widget ("cb_debug")->get_active || 0;
 
-  # Verbose mkisofs output.
-  $opt_verbose = $xml_root->get_widget ("cb_verbose")->get_active || 0;
+    # Verbose mkisofs output.
+    $opt_verbose = $xml_root->get_widget ("cb_verbose")->get_active || 0;
 
-  # Donnot delete tmp dir.
-  $opt_nodelete = $xml_root->get_widget ("cb_nodelete")->get_active || 0;
+    # Donnot delete tmp dir.
+    $opt_nodelete = $xml_root->get_widget ("cb_nodelete")->get_active || 0;
+  }
 
   # Temporary directory.
-  $opt_tmpdir = $xml_root->get_widget ("fileentry_tmpdir")->get_full_path(0);
+  $opt_tmpdir = $xml_root->get_widget ("fileentry_tmpdir")->get_full_path(0)
+    unless (defined $opt_nogui);
   $opt_tmpdir =~ s/([^\/])$/$1\// ;
 
   #######
   ## mkisofs options
   #######
-  $extra_mkisofs_options =
-    $xml_root->get_widget ("entry_extra_mkisofs_options")->get_text;
-  #######
-  ## mplayer options
-  #######
-  $extra_mplayer_options =
-    $xml_root->get_widget ("entry_extra_mplayer_options")->get_text;
-  $unwanted_mplayer_options =
-    $xml_root->get_widget ("entry_unwanted_mplayer_options")->get_text;
-  #######
-  ## [e]MoviX[] Options
-  #######
-  # Default language.
-  $opt_lang = $xml_root->get_widget ("entry_language")->get_text;
+  if (!defined $opt_nogui) {
+    $extra_mkisofs_options =
+      $xml_root->get_widget ("entry_extra_mkisofs_options")->get_text;
+    #######
+    ## mplayer options
+    #######
+    $extra_mplayer_options =
+      $xml_root->get_widget ("entry_extra_mplayer_options")->get_text;
+    $unwanted_mplayer_options =
+      $xml_root->get_widget ("entry_unwanted_mplayer_options")->get_text;
+    #######
+    ## [e]MoviX[] Options
+    #######
+    # Default boot help language.
+    $opt_boot_help_lang = $xml_root->get_widget ("entry_boot_help_lang")->get_text;
 
-  # Default keyboard layout.
-  $opt_kblayout = $xml_root->get_widget ("entry_kblayout")->get_text;
+    # Default keyboard layout.
+    $opt_kblayout = $xml_root->get_widget ("entry_kblayout")->get_text;
 
-  # Default fontset.
-  $opt_fontset = $xml_root->get_widget ("entry_fontset")->get_text;
+    # Default fontset.
+    $opt_fontset = $xml_root->get_widget ("entry_fontset")->get_text;
 
-  # Default bootlabel.
-  $opt_bootlabel = $xml_root->get_widget ("entry_bootlabel")->get_text;
+    # Default bootlabel.
+    $opt_bootlabel = $xml_root->get_widget ("entry_bootlabel")->get_text;
 
-  # Include Quicktime codecs ?
-  $opt_qt = $xml_root->get_widget ("cb_qt")->get_active || 0;
+    # Include Quicktime codecs ?
+    $opt_qt = $xml_root->get_widget ("cb_qt")->get_active || 0;
 
-  # Include ASF codecs ?
-  $opt_asf = $xml_root->get_widget ("cb_asf")->get_active || 0;
+    # Include ASF codecs ?
+    $opt_asf = $xml_root->get_widget ("cb_asf")->get_active || 0;
 
-  # Include WMV codecs ?
-  $opt_wmv = $xml_root->get_widget ("cb_wmv")->get_active || 0;
+    # Include WMV codecs ?
+    $opt_wmv = $xml_root->get_widget ("cb_wmv")->get_active || 0;
 
-  # Play movies in random order
-  $opt_random = $xml_root->get_widget ("cb_random")->get_active || 0;
+    # Play movies in random order
+    $opt_random = $xml_root->get_widget ("cb_random")->get_active || 0;
 
-  # Power off PC after playing all CD files
-  $opt_shut = $xml_root->get_widget ("cb_shut")->get_active || 0;
+    # Power off PC after playing all CD files
+    $opt_shut = $xml_root->get_widget ("cb_shut")->get_active || 0;
 
-  # Reboot PC after playing all CD files
-  $opt_reboot = $xml_root->get_widget ("cb_reboot")->get_active || 0;
+    # Reboot PC after playing all CD files
+    $opt_reboot = $xml_root->get_widget ("cb_reboot")->get_active || 0;
 
-  # Eject the CD
-  $opt_eject = $xml_root->get_widget ("cb_eject")->get_active || 0;
+    # Eject the CD
+    $opt_eject = $xml_root->get_widget ("cb_eject")->get_active || 0;
 
-  # Disable DMA
-  $opt_nodma = $xml_root->get_widget ("cb_nodma")->get_active || 0;
+    # Disable DMA
+    $opt_nodma = $xml_root->get_widget ("cb_nodma")->get_active || 0;
 
-  # Loop the playlist N times.
-  $opt_loop = $xml_root->get_widget ("entry_loop")->get_text;
+    # Loop the playlist N times.
+    $opt_loop = $xml_root->get_widget ("spinbutton_loop")->get_value_as_int;
 
-  $xml_root->get_widget ("prop_apply_btn")->set_sensitive(FALSE);
+    # MoviX option
+    $opt_menu_lang = $xml_root->get_widget("optionmenu_menu_lang")->get_menu->get_active->get_name;
+
+    ## End of options fetching
+
+    $xml_root->get_widget ("prop_apply_btn")->set_sensitive(FALSE);
+  }
 
   if ($opt_debug) {
     print STDERR <<EOL
@@ -466,7 +560,8 @@ EXTRA_MKISOFS_OPTIONS = "$extra_mkisofs_options"
 EXTRA_MPLAYER_OPTIONS = "$extra_mplayer_options"
 UNWANTED_MPLAYER_OPTIONS = "$unwanted_mplayer_options"
 OPT_TMPDIR = "$opt_tmpdir"
-OPT_LANG = "$opt_lang"
+OPT_BOOT_HELP_LANG = "$opt_boot_help_lang"
+OPT_MENU_LANG = "$opt_menu_lang"
 OPT_KBLAYOUT = "$opt_kblayout"
 OPT_FONTSET = "$opt_fontset"
 OPT_BOOTLABEL = "$opt_bootlabel"
@@ -527,8 +622,11 @@ sub reenable {
 # Display error dialog
 sub error {
   my ($err_msg) = @_;
+  print STDERR "ERROR : $err_msg\n"
+    if ($opt_debug || (defined $opt_nogui));
+  return if (defined $opt_nogui);
+
   $statusbar->set_status("An error has occured!");
-  print STDERR "ERROR : $err_msg\n" if ($opt_debug);
 
   my $diag_error =
   	new Gtk2::MessageDialog ($xml_root->get_widget ('MoviXMaker'),
@@ -542,7 +640,9 @@ sub error {
 # Display warning dialog
 sub warning {
   my ($err_msg) = @_;
-  print STDERR "WARNING : $err_msg\n" if ($opt_debug);
+  print STDERR "WARNING : $err_msg\n"
+    if ($opt_debug | (defined $opt_nogui));
+  return if (defined $opt_nogui);
 
   my $diag_warning =
   	new Gtk2::MessageDialog ($xml_root->get_widget ('MoviXMaker'),
@@ -553,21 +653,25 @@ sub warning {
 
 
 sub create_iso {
+  use vars qw($progress $diag_progress $fbtext $fbtextbuffer $output $coutput);
+
   # Create temp dir and update the global variable
   $tmpfolder = create_tmp_folder();
 
-  my $fbtext = $xml_root->get_widget ("fbtext");
-  my $fbtextbuffer;
+  unless (defined $opt_nogui)
+    {
+      $fbtext = $xml_root->get_widget ("fbtext");
 
-  # Verbose mkisofs in dialog if enabled
-  if ($opt_verbose) {
-    $fbtextbuffer = $fbtext->get_buffer;
-    $fbtextbuffer->delete($fbtextbuffer->get_iter_at_offset(0),
-			  $fbtextbuffer->get_iter_at_offset(-1));
-    $diag_feedback->show_all();
-  }
+      # Verbose mkisofs in dialog if enabled
+      if ($opt_verbose) {
+	$fbtextbuffer = $fbtext->get_buffer;
+	$fbtextbuffer->delete($fbtextbuffer->get_iter_at_offset(0),
+			      $fbtextbuffer->get_iter_at_offset(-1));
+	$diag_feedback->show_all();
+      }
 
-  $statusbar->set_status("Calling mkisofs...");
+      $statusbar->set_status("Calling mkisofs...");
+    }
 
   ############## TAKEN FROM mkmovixiso ###########
   ##################
@@ -589,63 +693,75 @@ sub create_iso {
 		    "-A '$movixversion' . 2>&1 |");
   print STDERR "CHILD_PID : $child_pid\n" if ($opt_debug);
 
-  my $progress = $xml_root->get_widget ("progressbar");
-  my $diag_progress = $xml_root->get_widget ("diag_progress");
+  unless (defined $opt_nogui)
+    {
+      $progress = $xml_root->get_widget ("progressbar");
+      $diag_progress = $xml_root->get_widget ("diag_progress");
 
-  $progress->set_fraction(0);
-  $diag_progress->show;
-
-  my $output; # current line
-  my $coutput; # complete output
+      $progress->set_fraction(0);
+      $diag_progress->show;
+    }
 
   while (<CMDEXEC>)
     {
       if ( $_ =~ /([0-9]{1,2}).*done.*(estimate)/i ) {
 	my $value = $1;
-	print STDERR "WRITING PROGRESS : $value %\n" if ($opt_debug);
-	$progress->set_fraction($value/100);
-      } elsif ( $_ =~ /(writing|scanning)/i ) {
+	print STDERR "WRITING PROGRESS : $value %\n"
+	  if ($opt_debug || (defined $opt_nogui));
+	$progress->set_fraction($value/100) unless (defined $opt_nogui);
+      } elsif ( $_ =~ /(writing|scanning)/i and (!defined $opt_nogui)) {
 	$diag_progress->set_title($1);
 	$statusbar->set_status($1);
       } elsif ( $_ =~ /mkisofs:\sWarning:\s(.*)/ ) {
-	print STDERR "WARNING : $1\n"  if($opt_debug);
-      ######
-      # Detecting mkisofs errors and rejecting Warnings
+	print STDERR "WARNING : $1\n"
+	  if($opt_debug || (defined $opt_nogui));
+	######
+	# Detecting mkisofs errors and rejecting Warnings
       } elsif ( $_ =~ /mkisofs:(.*)/ ) {
-	$diag_progress->hide;
+	$diag_progress->hide unless (defined $opt_nogui);
 	error($1);
       }
 
       $output = $_;
       $coutput .= $_;
 
-      if ($opt_verbose) {
-	my $iter = $fbtextbuffer->get_iter_at_offset(-1); # -1 = end of buffer
-	$fbtextbuffer->insert($iter, $output);
-      }
+      unless (defined $opt_nogui) {
+	if ($opt_verbose) {
+	  my $iter = $fbtextbuffer->get_iter_at_offset(-1); # -1 = end of buffer
+	  $fbtextbuffer->insert($iter, $output);
+	}
 
-      while (Gtk2->events_pending) {
-	Gtk2->main_iteration();
+	while (Gtk2->events_pending) {
+	  Gtk2->main_iteration();
+	}
       }
     }
+
   ######
   # Detecting if it created the disc image
-  if ( $coutput =~ /extents\swritten\s\(([0-9]+\sMb)\)/ ) {
-    $diag_progress->hide;
+  if ( $coutput =~ /extents\swritten\s\(([0-9]+\sMb)\)/i ) {
     my $disc_image_size = $1;
-    print STDERR "WROTE : $disc_image_size\n" if ($opt_debug);
-    $statusbar->set_status("Disc image created! ($disc_image_size)");
-    reenable();
+    print STDERR "WROTE : $disc_image_size\n"
+      if ($opt_debug or (defined $opt_nogui));
+    unless (defined $opt_nogui) {
+      $diag_progress->hide;
+      $statusbar->set_status("Disc image created! ($disc_image_size)");
+      reenable();
+    }
   ######
   # Special treatment for mkisofs --help
   } elsif ( $coutput =~ /Usage:\s(.*)/ ) {
     $coutput =~ s/^.*Warning.*\n//; # We don't want the warnings to be displayed
-    $diag_progress->hide;
-    $fbtextbuffer->delete($fbtextbuffer->get_iter_at_offset(0),
-			  $fbtextbuffer->get_iter_at_offset(-1));
-    $fbtextbuffer->insert($fbtextbuffer->get_iter_at_offset(0), $coutput);
-    $diag_feedback->show_all();
-    reenable();
+    if (defined $opt_nogui) {
+      print "$coutput\n";
+    } else {
+      $diag_progress->hide;
+      $fbtextbuffer->delete($fbtextbuffer->get_iter_at_offset(0),
+			    $fbtextbuffer->get_iter_at_offset(-1));
+      $fbtextbuffer->insert($fbtextbuffer->get_iter_at_offset(0), $coutput);
+      $diag_feedback->show_all();
+      reenable();
+    }
   }
   ######
   # Deleting the temporary directory
@@ -660,12 +776,14 @@ sub get_movix_version {
 
   if ($installed_emovix) {
     $movixversion = "eMoviX-" . `echo -n \$(movix-version 2>/dev/null)`;
-    $statusbar->set_status("Detected $movixversion.");
-    print STDERR "FOUND : $movixversion\n" if ($opt_debug);
+    $statusbar->set_status("Detected $movixversion.") unless (defined $opt_nogui);
+    print STDERR "FOUND : $movixversion\n"
+      if ($opt_debug or (defined $opt_nogui));
     return;
   }
 
-  $statusbar->set_status("Attempting to detect MoviX version...");
+  $statusbar->set_status("Attempting to detect MoviX version...")
+    unless (defined $opt_nogui);
 
   $movixversion = "";
 
@@ -687,19 +805,38 @@ sub get_movix_version {
 
     if ( $version =~ /(e?MoviX2?[-\s]([0-9]\.){2}[0-9]((pre|rc)[0-9]{1,2})?(cvs[0-9]{8})?)/ ) {
       $movixversion = $1;
-      $statusbar->set_status("Detected $movixversion.");
-      print STDERR "FOUND : $movixversion\n" if ($opt_debug);
+      $statusbar->set_status("Detected $movixversion.") unless (defined $opt_nogui);
+
+      if (!defined $opt_nogui) {
+	# Menu and MPlayer languages currently for MoviX only.
+	if ($movixversion =~ /^MoviX[^2]/) {
+	  $xml_root->get_widget ("optionmenu_menu_lang")->set_sensitive(TRUE);
+	} else {
+	  $xml_root->get_widget ("optionmenu_menu_lang")->set_sensitive(FALSE);
+	}
+      }
+
+      print STDERR "FOUND : $movixversion\n"
+	if ($opt_debug or (defined $opt_nogui));
+    } else {
+      if (defined $opt_nogui) {
+	print "Not a valid *MoviX* directory.\n";
+      } else {
+	$statusbar->set_status("Not a valid *MoviX* directory.");
+      }
+    }
+  } else {
+    if (defined $opt_nogui) {
+      print "Not a valid *MoviX* directory.\n";
     } else {
       $statusbar->set_status("Not a valid *MoviX* directory.");
     }
-  } else {
-    $statusbar->set_status("Not a valid *MoviX* directory.");
     return;
   }
 }
 
-# Tries to detect the available languages
-sub get_languages {
+# Tries to detect the available boot help languages
+sub get_boot_help_languages {
   my $dir = "${srcpath}boot-messages";
   opendir (LP, $dir);
   my @files = grep { /^[a-z]{2,3}$/ && -d "$dir/$_" } readdir(LP);
@@ -748,10 +885,10 @@ sub get_bootlabels {
   return $list;
 }
 
-sub validate_language {
+sub validate_boot_help_language {
   my $choosen_lang;
-  foreach my $lang (@languages) {
-    $choosen_lang = $opt_lang if ($lang =~ /$opt_lang/);
+  foreach my $lang (@boot_help_langs) {
+    $choosen_lang = $opt_boot_help_lang if ($lang =~ /$opt_boot_help_lang/);
   }
   return "en" unless $choosen_lang;
 }
@@ -781,18 +918,18 @@ sub validate_bootlabel {
 }
 
 sub get_movix_options {
-  @languages = get_languages;
+  @boot_help_langs = get_boot_help_languages;
   @kblayouts = get_kblayouts;
   @fontsets = get_fontsets;
   $bootlabels = get_bootlabels();
-  $opt_lang = validate_language();
+  $opt_boot_help_lang = validate_boot_help_language();
   $opt_kblayout = validate_kblayout();
   $opt_fontset = validate_fontset();
   $opt_bootlabel = validate_bootlabel();
 
-  if ($opt_debug) {
-    print STDERR "FOUND LANGUAGE(S) : ";
-    foreach my $file (@languages) {
+  if ($opt_debug or (defined $opt_nogui)) {
+    print STDERR "FOUND BOOT HELP LANGUAGE(S) : ";
+    foreach my $file (@boot_help_langs) {
       print STDERR "$file ";
     }
     print STDERR ".\n";
@@ -808,53 +945,73 @@ sub get_movix_options {
     print STDERR ".\n";
     print STDERR
       "FOUND BOOTLABELS : " . $bootlabels . ".\n".
-	"EFFECTIVE LANG : " . $opt_lang . ".\n".
-	  "EFFECTIVE KBLAYOUT : " . $opt_kblayout . ".\n".
-	    "EFFECTIVE FONTSET : " . $opt_fontset . ".\n".
-	      "EFFECTIVE BOOTLABEL : " . $opt_bootlabel . ".\n";
+	"EFFECTIVE BOOT HELP LANG : " . $opt_boot_help_lang . ".\n";
+
+    if (defined $opt_menu_lang and $movixversion =~ /^MoviX[^2]/) {
+      print STDERR "EFFECTIVE MENU LANG : " . $opt_menu_lang . ".\n";
+    }
+
+    print STDERR
+      "EFFECTIVE KBLAYOUT : " . $opt_kblayout . ".\n".
+	"EFFECTIVE FONTSET : " . $opt_fontset . ".\n".
+	  "EFFECTIVE BOOTLABEL : " . $opt_bootlabel . ".\n";
   }
 }
 
 sub prepare_iso {
-  $destpath = $destination->get_full_path(0);
-  $srcpath = $srcdir->get_full_path(0);
+  if (!defined $opt_nogui) {
+    $destpath = $destination->get_full_path(0);
+    $srcpath = $srcdir->get_full_path(0);
+  }
+
   $srcpath =~ s/([^\/])$/$1\// ; # Add a trailing /
 
   print "Preparing ISO using movixDir: " . $srcpath . "\n"
-      if ($opt_debug);
+      if ($opt_debug or (defined $opt_nogui));
 
   get_movix_version();
 
   if (!$srcpath || !$destpath)
     {
-      $statusbar->set_status("Specify a dir and destination file!");
-      reenable();
+      if (defined $opt_nogui) {
+	print "Specify a dir and destination file!\n";
+	exit;
+      } else {
+	$statusbar->set_status("Specify a dir and destination file!");
+	reenable();
+      }
     }
   else
     {
       if (!$movixversion){
-	$statusbar->set_status("That's not a [e]MoviX[] dir!");
-	reenable();
+	if (defined $opt_nogui) {
+	  print "$srcpath is not a [e]MoviX[] directory!";
+	  exit;
+	} else {
+	  $statusbar->set_status("That's not a [e]MoviX[] dir!");
+	  reenable();
+	}
       } else {
 	# Now that we know that it's a valid *MoviX* path, let's detect
 	# what's available.
 	get_movix_options();
 
-	# Update the interface with avail. options
-	update_options();
+	if (defined $opt_nogui) {
+	  create_iso() if (defined $srcpath);
+	} else {
+	  # Update the interface with avail. options
+	  update_options();
 
-	# Did the user toggled the "Do not customize disc image" checkbox ?
-	if ($xml_root->get_widget ("cb_nocustomize")->get_active)
-	  {
+	  # Did the user toggled the "Do not customize disc image" checkbox ?
+	  if ($xml_root->get_widget ("cb_nocustomize")->get_active) {
 	    # Directly creating the image, no customization
 	    create_iso() if (defined $srcpath);
-	  }
-	else
-	  {
+	  } else {
 	    # Let's choose the options
 	    $xml_root->get_widget ("diag_customize")->show()
 	      if (defined $srcpath);
 	  }
+	}
       }
     }
 }
@@ -907,9 +1064,9 @@ sub create_tmp_folder {
     system "rm -f isolinux/isolinux.bin";
     system "cp ${srcpath}${src}isolinux/isolinux.bin isolinux/isolinux.bin";
 
-    if ( -e $srcpath . "boot-messages/" . $opt_lang ) {
+    if ( -e $srcpath . "boot-messages/" . $opt_boot_help_lang ) {
       system "rm -f isolinux/*txt";
-      system "ln -s ${srcpath}boot-messages/${opt_lang}/*txt isolinux";
+      system "ln -s ${srcpath}boot-messages/${opt_boot_help_lang}/*txt isolinux";
     }
 
     if ( -e $srcpath . "mplayer-fonts" ) {
@@ -934,17 +1091,22 @@ sub create_tmp_folder {
       close CFG;
     }
 
+    # Creating the file containing the default [e]MoviX[2] boot parameters
     open BOOTRC, "> movix/bootrc";
     print BOOTRC "EXTRA-MPLAYER-OPTIONS=$extra_mplayer_options\n"
       if (defined $extra_mplayer_options && $extra_mplayer_options);
     print BOOTRC "UNWANTED-MPLAYER-OPTIONS=$unwanted_mplayer_options\n"
       if (defined $unwanted_mplayer_options && $unwanted_mplayer_options);
-    print BOOTRC "LOOP=$opt_loop\n" if ($opt_loop != 0);
+    print BOOTRC "LOOP=$opt_loop\n" if ($opt_loop =~ /[0-9]+/);
     print BOOTRC "SHUT=y\n"     if ($opt_shut != 0);
     print BOOTRC "REBOOT=y\n"   if ($opt_reboot != 0);
     print BOOTRC "RANDOM=y\n"   if ($opt_random != 0);
     print BOOTRC "EJECT=y\n"    if ($opt_eject != 0);
     print BOOTRC "DMA=n\n"      if ($opt_nodma != 0);
+    print BOOTRC "KB=$opt_kblayout\n"
+      if ($movixversion =~ /^MoviX/ and $opt_kblayout =~ /[a-z]{2}(\-[a-z]{2})?/);
+    print BOOTRC "LANGUAGE=$opt_menu_lang\n"
+      if ($movixversion =~ /^MoviX[^2]/ and $opt_menu_lang =~ /[a-z]{2}(\-[a-z]{2})?/);
     close BOOTRC;
 
     chdir  "$origDir";
@@ -955,7 +1117,6 @@ sub create_tmp_folder {
   }
 }
 
-######## TAKEN FROM mkmovixiso ############
 ####  Command line help
 ######################
 sub help {
@@ -969,14 +1130,16 @@ Options:
 
    --verbose               Verbose mkisofs output
    --debug                 Debug mode (kind of movixmaker verbose)
-   --version               Displays MoviXMaker's version and exits
+   --version               Displays MoviXMaker-2's version and exits
+   --nogui                 Do not show the graphical interface
    --nodelete              Don't delete temporary directory
    --output-file=<file>    Name [with full path!] of the output iso image
    --tmpDir=<path>         Directory that will contain the temporary files
 
  *MoviX*:
    --boot-label=<label>    Make MoviX boot by default with your favorite label
-   --language=<lang>       Specify the language of the CD boot messages
+   --boot-help-lang=<lang> Specify the language of the CD boot help messages
+   --menu-lang=<lang>      Specify the MoviX/MPlayer menu language
    --keyboard=<lang>       Specify the keyboard layout to use
    --movixDir=<dir>        Location of the *movix* directory
    --loop=<k>              Make MPlayer play k times your files before stopping
@@ -1010,8 +1173,8 @@ MoviXMaker-2 - Easily create customized eMoviX/MoviX/MoviX2 disc images
 =head1 SYNOPSIS
 
     movixmaker-2[.pl] [--version|--help] [--verbose] [--debug]
-                  [--nodelete] [--language=Language]
-                  [--subtitleFonts=FontSet]
+                  [--nogui] [--nodelete] [--boot-help-lang=Language]
+                  [--menu-lang=Language] [--subtitleFonts=FontSet]
                   [--keyboard=KbLayout] [--movix=MovixSrcDir]
                   [-o=OutputFile] [-t=TempDir] [-b=BootLabel]
                   [--loop=NbrOfLoops] [--random] [--nodma]
@@ -1023,8 +1186,9 @@ MoviXMaker-2 - Easily create customized eMoviX/MoviX/MoviX2 disc images
 
 =head1 DESCRIPTION
 
-I<MoviXMaker> is a simple Perl GTK+-2/Gnome2/GladeXML interface to create
-customized eMoviX/MoviX/MoviX ISO files.
+I<MoviXMaker> is a simple Perl command line utility or a
+GTK+-2/Gnome2/GladeXML interface to create customized
+eMoviX/MoviX/MoviX ISO files.
 
 It includes disc image customization possibilities such as :
  - language, keyboard layout, subtitle fontset, boot label
@@ -1069,6 +1233,14 @@ Debug mode (kind of movixmaker-2 verbose).
 
 =back
 
+=head2 --nogui
+
+=over
+
+Do not display the graphical interface.
+
+=back
+
 =head2 --nodelete
 
 =over
@@ -1077,11 +1249,19 @@ Don't delete temporary directory.
 
 =back
 
-=head2 --language=I<Language>
+=head2 --boot-help-lang=I<Language>
 
 =over
 
-Specify the language of the CD boot messages.
+Specify the language of the CD boot help messages.
+
+=back
+
+=head2 --menu-lang=I<Language>
+
+=over
+
+Specify the MoviX/MPlayer menu language.
 
 =back
 
